changeset 17194:f4c6c1bc5e41 v8.1.1596

patch 8.1.1596: when resizing the screen may draw popup in wrong position commit https://github.com/vim/vim/commit/c2a43165004f944a909428e80700130745c08ed0 Author: Bram Moolenaar <Bram@vim.org> Date: Wed Jun 26 01:03:53 2019 +0200 patch 8.1.1596: when resizing the screen may draw popup in wrong position Problem: When resizing the screen may draw popup in wrong position. (Masato Nishihata) Solution: Check the popup is not outside of the screen. (fixes #4592)
author Bram Moolenaar <Bram@vim.org>
date Wed, 26 Jun 2019 01:15:17 +0200
parents 1bd075bf6f8b
children 44d92eb813b4
files src/popupwin.c src/version.c
diffstat 2 files changed, 5 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/src/version.c
+++ b/src/version.c
@@ -778,6 +778,8 @@ static char *(features[]) =
 static int included_patches[] =
 {   /* Add new patch number below this line */
 /**/
+    1596,
+/**/
     1595,
 /**/
     1594,
--- a/src/popupwin.c
+++ b/src/popupwin.c
@@ -2154,8 +2154,9 @@ update_popups(void (*win_update)(win_T *
 	wp->w_winrow += top_off;
 	wp->w_wincol += left_off;
 
-	// Draw the popup text.
-	win_update(wp);
+	// Draw the popup text, unless it's off screen.
+	if (wp->w_winrow < screen_Rows && wp->w_wincol < screen_Columns)
+	    win_update(wp);
 
 	wp->w_winrow -= top_off;
 	wp->w_wincol -= left_off;